@@ -100,7 +100,7 @@ int conn_set( conn_t *conn, char *set_url )
 			/* Dash the password: Save traffic by trying
 			   to avoid multi-line responses		*/
 			strcpy( conn->user, "anonymous" );
-			strcpy( conn->pass, "-lara_hack@gmx.co.uk" );
+			strcpy( conn->pass, "mailto:axel-devel@lists.alioth.debian.org" );
 		}
 		else
 		{
@@ -242,7 +242,7 @@ int conn_setup( conn_t *conn )
 		
 		if( conn->currentbyte )
 		{
-			ftp_command( conn->ftp, "REST %i", conn->currentbyte );
+			ftp_command( conn->ftp, "REST %lld", conn->currentbyte );
 			if( ftp_wait( conn->ftp ) / 100 != 3 &&
 			    conn->ftp->status / 100 != 2 )
 				return( 0 );
@@ -251,11 +251,15 @@ int conn_setup( conn_t *conn )
 	else
 	{
 		char s[MAX_STRING];
-		
+		int i;
+
 		snprintf( s, MAX_STRING, "%s%s", conn->dir, conn->file );
 		conn->http->firstbyte = conn->currentbyte;
 		conn->http->lastbyte = conn->lastbyte;
 		http_get( conn->http, s );
+		http_addheader( conn->http, "User-Agent: %s", conn->conf->user_agent );
+		for( i = 0; i < conn->conf->add_header_count; i++)
+			http_addheader( conn->http, "%s", conn->conf->add_header[i] );
 	}
 	return( 1 );
 }
@@ -282,12 +286,12 @@ int conn_info( conn_t *conn )
 	/* It's all a bit messed up.. But it works.			*/
 	if( conn->proto == PROTO_FTP && !conn->proxy )
 	{
-		ftp_command( conn->ftp, "REST %i", 1 );
+		ftp_command( conn->ftp, "REST %lld", 1 );
 		if( ftp_wait( conn->ftp ) / 100 == 3 ||
 		    conn->ftp->status / 100 == 2 )
 		{
 			conn->supported = 1;
-			ftp_command( conn->ftp, "REST %i", 0 );
+			ftp_command( conn->ftp, "REST %lld", 0 );
 			ftp_wait( conn->ftp );
 		}
 		else
@@ -308,7 +312,7 @@ int conn_info( conn_t *conn )
 	else
 	{
 		char s[MAX_STRING], *t;
-		int i = 0;
+		long long int i = 0;
 		
 		do
 		{
